@@ -43,12 +43,23 @@ class Options(argparse.ArgumentParser):
         so = SnakemakeOptions(working_directory=NAME)
         so.add_options(self)
 
-        so = InputOptions()
+        so = InputOptions(add_input_readtag=False)
         so.add_options(self)
 
         so = GeneralOptions()
         so.add_options(self)
 
+
+        pipeline_group = self.add_argument_group("sequana_fastqc")
+        pipeline_group.add_argument("--method", dest="method",
+            default="fastqc", choices=['fastqc', 'falco'], 
+            help="""Software to be used to perform QC of input data set,
+                Standard tool is fastqc (default), but one can use falco, which is 3-4 faster
+                and produces same plots""")
+        #pipeline_group.add_argument("--data-type", dest="data_type",
+        #    default="illumina", choices=['illumina', 'nanopore', 'pacbio', 'mgi', 'others'], 
+        #    help="""nanopore, others and pacbio are not paired. The --input-readtag then be ignored""")
+
         self.add_argument("--run", default=False, action="store_true",
             help="execute the pipeline directly")
 
@@ -92,14 +103,16 @@ def main(args=None):
     if options.from_project is None:
         cfg = manager.config.config
         cfg.input_pattern = options.input_pattern
-        cfg.input_readtag = options.input_readtag
         cfg.input_directory = os.path.abspath(options.input_directory)
+        cfg.general.method_choice = options.method
 
         manager.exists(cfg.input_directory)
 
     # finalise the command and save it; copy the snakemake. update the config
     # file and save it.
-    manager.teardown()
+    # Since input can be bam, fast5, mgi, the standard FastQFactory may not
+    # work, so we only check presence of input files. 
+    manager.teardown(check_fastq_files=False)
 
     if options.run:
         subprocess.Popen(["sh", '{}.sh'.format(NAME)], cwd=options.workdir)
